package client.cam;

import com.sun.image.codec.jpeg.JPEGCodec;
import com.sun.image.codec.jpeg.JPEGImageDecoder;
import java.applet.Applet;
import java.awt.Canvas;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.GridLayout;
import java.awt.Image;
import java.io.BufferedInputStream;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URL;

public class HsView extends Applet implements Runnable
{
	protected Thread				myThread;
	protected Canvas				can			= new Canvas();
	protected int					interval		= 10;
	protected String				imgName		= "img.jpg";
	protected int					width			= 640;
	protected int					height		= 480;
	protected volatile boolean	menAtWork	= true;

	public void init()
	{
		this.getInitParm();
		this.setLayout(new GridLayout());
		this.setBackground(Color.white);
		this.can.setBounds(0, 0, this.width, this.height);
		this.add(this.can);
		this.myThread = new Thread(this);
	}

	protected void getInitParm()
	{
		this.interval = this.getIntParm("interval", this.interval);
		this.width = this.getIntParm("image_width", this.width);
		this.height = this.getIntParm("image_height", this.height);
		this.imgName = this.getStringParm("image", this.imgName);
	}

	protected String getStringParm(String string, String string2)
	{
		String string3 = this.getParameter(string);
		if (string3 != null)
		{
			string2 = string3;
		}
		return string2;
	}

	protected int getIntParm(String string, int n)
	{
		String string2 = this.getParameter(string);
		if (string2 != null)
		{
			n = Integer.valueOf(string2);
		}
		return n;
	}

	public void start()
	{
		if (this.myThread != null)
		{
			this.myThread.start();
		}
	}

	public void stop()
	{
		if (this.myThread != null)
		{
			this.menAtWork = false;
			if (this.myThread.isAlive())
			{
				this.myThread.interrupt();
			}
			try
			{
				this.myThread.join();
			}
			catch (InterruptedException interruptedException)
			{
				// empty catch block
			}
		}
	}

	public void destroy()
	{
		this.myThread = null;
	}

	public void run()
	{
		Image image = null;
		while (this.myThread != null && this.menAtWork)
		{
			if (this.menAtWork)
			{
				image = this.readImage(this.imgName);
			}
			if (this.menAtWork && image != null)
			{
				this.draw(image);
			}
			this.sleep(this.interval);
			if (image == null)
				continue;
			image.flush();
			image = null;
		}
	}

	protected Image readImage(String string)
	{
		Image image = null;
		HttpURLConnection httpURLConnection = null;
		BufferedInputStream bufferedInputStream = null;
		URL uRL = null;
		try
		{
			uRL = new URL(this.getCodeBase(), string);
			if (uRL == null)
			{
				System.out.println("err : URL cannot be created\r\n");
				return null;
			}
			httpURLConnection = (HttpURLConnection) uRL.openConnection();
			if (httpURLConnection == null)
			{
				System.out.println("err : HttpURLConnection cannot be created\r\n");
				return null;
			}
			httpURLConnection.setRequestMethod("GET");
			httpURLConnection.setUseCaches(false);
			bufferedInputStream = new BufferedInputStream(httpURLConnection.getInputStream());
			if (bufferedInputStream == null)
			{
				this.closeConnect(httpURLConnection, bufferedInputStream);
				System.out.println("err : InputStream cannot be created\r\n");
				return null;
			}
			JPEGImageDecoder jPEGImageDecoder = JPEGCodec.createJPEGDecoder(bufferedInputStream);
			image = jPEGImageDecoder.decodeAsBufferedImage();
		}
		catch (Exception exception)
		{
			System.err.println("ERROR: " + exception);
			this.closeConnect(httpURLConnection, bufferedInputStream);
			if (image != null)
			{
				image.flush();
				image = null;
			}
			return null;
		}
		this.closeConnect(httpURLConnection, bufferedInputStream);
		return image;
	}

	protected void closeConnect(HttpURLConnection httpURLConnection, InputStream inputStream)
	{
		if (inputStream != null)
		{
			try
			{
				inputStream.close();
			}
			catch (Exception exception)
			{
				// empty catch block
			}
		}
		if (httpURLConnection != null)
		{
			httpURLConnection.disconnect();
		}
	}

	protected void draw(Image image)
	{
		Graphics graphics = this.can.getGraphics();
		if (image != null)
		{
			graphics.drawImage(image, 0, 0, this);
		}
	}

	protected void sleep(int n)
	{
		try
		{
			Thread.currentThread();
			Thread.sleep(n);
		}
		catch (Exception exception)
		{
			// empty catch block
		}
	}
}
